/////////////////////////////////////////////////////////////////////////////
// Hearts.h - Header file for main application
//
// Hearts Card Game
// Copyright (C) 2001 Leo C. Singleton IV
// http://www.leosingleton.com/projects/hearts/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; version 2 of the
// License. 
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
// 02110-1301, USA.
/////////////////////////////////////////////////////////////////////////////

/////////////////////////////////////////////////////////////////////////////
// Revision History
//
// 8/8/01 LCS - changed #includes; removed #defines needed to upgrade from
//		Palm OS SDK 3.1 to SDK 4.0
// 9/28/01 LCS - removed debugging and dead code
// 12/30/01 LCS - added wide character support
// 6/6/02 LCS - added MarkPlayableCards and Difficulty preferences;
//		incremented preferences version number
/////////////////////////////////////////////////////////////////////////////


#if !defined(__HEARTS_H__)
#define __HEARTS_H__


#include <PalmOS.h>
#include "Resource.h"


#define appCreatorID	'HEAR'
#define appPrefID		0
#define appGameID		1
#define appPrefVersion	3


typedef struct
{
	UInt8 AnimationDelay;
	UInt8 AnimationSpeed;
	char Names[4][26];
	Boolean MarkPlayableCards;
	UInt8 Difficulty;
} Prefs_Type;


typedef struct
{
	UInt8 Cards[4][13];
	Boolean Used[4][13];
	UInt8 GameStatus;
	UInt8 PassTo;
	UInt8 Turn;
	UInt8 Play[4];
	UInt8 Tricks;
	UInt8 TrickWinner;
	Boolean HeartsBroken;
	UInt8 AnimCount;
	UInt8 SuitLed;
	UInt8 RoundScore[4];
	UInt16 TotalScore[4];
	UInt8 CurrentSelection;
	UInt8 CardPassCount;
	Boolean Invert[13];
	
	Int16 AnimStartX, AnimStartY, AnimEndX, AnimEndY;
	Int16 AnimLastX, AnimLastY;
	UInt8 AnimProgress;
	UInt8 AnimCard, AnimSuit;
} Game_Type;


extern UInt8 AnimCount;
extern Prefs_Type Prefs;
extern Game_Type Game;


#define GAMESTATUS_NOGAME		0
#define GAMESTATUS_SELECTPASS	1
#define GAMESTATUS_ACCEPTPASS	2
#define GAMESTATUS_SELECTCARD	3
#define GAMESTATUS_ANIMATE		4
#define GAMESTATUS_GAMEOVER		5

#define PREF_ANIMSPEED_SLOW		1
#define PREF_ANIMSPEED_MED		4
#define PREF_ANIMSPEED_FAST		10

#define PREF_ANIMSMOOTH_LOW		20
#define PREF_ANIMSMOOTH_MED		5
#define PREF_ANIMSMOOTH_HIGH	2

#define PREF_DIFFICULTY_EASY	0
#define PREF_DIFFICULTY_MEDIUM	1
#define PREF_DIFFICULTY_HARD	2


// this global variable will be set during startup to indicate whether to use
// regular chars (prior to OS 3.1) or WChar (OS 3.1 and greater)
extern Boolean WideCharacterSupport;


#endif // __HEARTS_H__

